# Makefile for OpenVMS
# Author : Jouk Jansen
# Date : 7 March 2008

GMP_NAIL_BITS = 0
BITS_PER_MP_LIMB = 32

CFLAGS=/name=(as_is,short)/float=ieee/ieee=denorm/define=("__GMP_WITHIN_GMP=1")

OBJS=assert.obj,compat.obj,errno.obj,\
	extract-dbl.obj,invalid.obj,memory.obj,mp_bpl.obj,\
	mp_clz_tab.obj,mp_dv_tab.obj,mp_minv_tab.obj,\
	mp_get_fns.obj,mp_set_fns.obj,rand.obj,randclr.obj,\
	randdef.obj,randiset.obj,randlc2s.obj,randlc2x.obj,\
	randmt.obj,randmts.obj,rands.obj,randsd.obj,randsdui.obj,\
	randbui.obj,randmui.obj,version.obj,tal-reent.obj

all : config.h gmp.h mp.h gmp-mparam.h fib_table.h mp_bases.h [.mpz]fac_ui.h\
	[.mpn]fib_table.c [.mpn]mp_bases.c [.mpn]perfsqr.h
	set default [.mpf]
        $(MMS)$(MMSQUALIFIERS)
	set default [-.mpz]
        $(MMS)$(MMSQUALIFIERS)
	set default [-.mpq]
        $(MMS)$(MMSQUALIFIERS)
	set default [-.mpn]
        $(MMS)$(MMSQUALIFIERS)
	set default [.generic]
	$(MMS)$(MMSQUALIFIERS)
	set default [--.printf]
        $(MMS)$(MMSQUALIFIERS)
	set default [-.scanf]
        $(MMS)$(MMSQUALIFIERS)
	set default [-]
	$(MMS)$(MMSQUALIFIERS) $(OBJS)
	library/create libgmp.olb $(OBJS)
	set default [.mpbsd]
        $(MMS)$(MMSQUALIFIERS)
	set default [-]
	@ WRITE_ SYS$OUTPUT "  generating libgmp.opt"
	@ library/extract=* libgmp
	@ library/extract=* libgmp_mpbsd
	@ library/extract=* libgmp_mpf
	@ library/extract=* libgmp_mpn
	@ library/extract=* libgmp_mpq
	@ library/extract=* libgmp_mpz
	@ library/extract=* libgmp_printf
	@ library/extract=* libgmp_scanf
	@ library/extract=* libgmp_generic
	@ OPEN_/WRITE FILE  libgmp.opt
	@ WRITE_ FILE "!"
	@ WRITE_ FILE "! libgmp.opt generated by DESCRIP.$(MMS_EXT)" 
	@ WRITE_ FILE "!"
	@ WRITE_ FILE "IDENTIFICATION=""libgmp"""
	@ WRITE_ FILE "GSMATCH=LEQUAL,4,2
	@ WRITE_ FILE "libgmp.obj"
	@ WRITE_ FILE "libgmp_mpbsd.obj"
	@ WRITE_ FILE "libgmp_mpf.obj"
	@ WRITE_ FILE "libgmp_mpn.obj"
	@ WRITE_ FILE "libgmp_mpq.obj"
	@ WRITE_ FILE "libgmp_mpz.obj"
	@ WRITE_ FILE "libgmp_printf.obj"
	@ WRITE_ FILE "libgmp_scanf.obj"
	@ WRITE_ FILE "libgmp_generic.obj"
	@ CLOSE_ FILE
	@ $(MMS)$(MMSQUALIFIERS)/ignore=warning gmp_vms
	@ WRITE_ SYS$OUTPUT "  linking libgmp.exe ..."
	@ LINK_/NODEB/SHARE=libgmp.exe/MAP=libgmp.map/FULL libgmp.opt/opt,gmp_vms.opt/opt
	@ delete libgmp*.obj;*
	$(MMS)$(MMSQUALIFIERS) check
	@ write sys$output "all done"

gmp_vms :
	@ WRITE_ SYS$OUTPUT "  generating libgmp.map ..."
	@ LINK_/NODEB/NOSHARE/NOEXE/MAP=libgmp.map/FULL libgmp.opt/OPT
	@ WRITE_ SYS$OUTPUT "  analyzing excel.map ..."
	@ @ANALYZE_MAP.COM libgmp.map gmp_vms.opt

check :
	set default [.tests]
	$(MMS)$(MMSQUALIFIERS)

config.h : config.h_vms
	copy config.h_vms config.h

fib_table.h : gen-fib.exe
	pipe mc []gen-fib header $(BITS_PER_MP_LIMB) $(GMP_NAIL_BITS) >fib_table.h

[.mpn]fib_table.c : gen-fib.exe
	pipe mc []gen-fib table $(BITS_PER_MP_LIMB) $(GMP_NAIL_BITS) > [.mpn]fib_table.c

mp_bases.h : gen-bases.exe
	pipe mc []gen-bases header $(BITS_PER_MP_LIMB) $(GMP_NAIL_BITS) >mp_bases.h

[.mpn]mp_bases.c : gen-bases.exe
	pipe mc []gen-bases table $(BITS_PER_MP_LIMB) $(GMP_NAIL_BITS) > [.mpn]mp_bases.c

[.mpn]perfsqr.h : gen-psqr.exe
	pipe mc []gen-psqr $(BITS_PER_MP_LIMB) $(GMP_NAIL_BITS) > [.mpn]perfsqr.h

gen-psqr.exe : gen-psqr.obj
	link gen-psqr.obj

gen-psqr.obj : gen-psqr.c

gen-fib.exe : gen-fib.obj
	link gen-fib.obj

gen-fib.obj : gen-fib.c

gen-bases.exe : gen-bases.obj
	link gen-bases.obj

gen-bases.obj : gen-bases.c

[.mpz]fac_ui.h : gen-fac_ui.exe
	pipe mc []gen-fac_ui $(BITS_PER_MP_LIMB) $(GMP_NAIL_BITS) > [.mpz]fac_ui.h

gen-fac_ui.exe : gen-fac_ui.obj
	link gen-fac_ui.obj	

gen-fac_ui.obj : gen-fac_ui.c

gmp.h : gmp.h_vms
	copy gmp.h_vms gmp.h

mp.h : mp.h_vms
	copy mp.h_vms mp.h

gmp-mparam.h : [.mpn.generic]gmp-mparam.h
	set file/enter=[]gmp-mparam.h [.mpn.generic]gmp-mparam.h

$(OBJS) : config.h gmp.h fib_table.h

assert.obj : assert.c
compat.obj : compat.c
errno.obj : errno.c
extract-dbl.obj : extract-dbl.c
invalid.obj : invalid.c
memory.obj : memory.c
mp_bpl.obj : mp_bpl.c
mp_clz_tab.obj : mp_clz_tab.c
mp_dv_tab.obj : mp_dv_tab.c
mp_minv_tab.obj : mp_minv_tab.c
mp_get_fns.obj : mp_get_fns.c
mp_set_fns.obj : mp_set_fns.c
rand.obj : rand.c
randclr.obj : randclr.c
randdef.obj : randdef.c
randiset.obj : randiset.c
randlc2s.obj : randlc2s.c
randlc2x.obj : randlc2x.c
randmt.obj : randmt.c
randmts.obj : randmts.c
rands.obj : rands.c
randsd.obj : randsd.c
randsdui.obj : randsdui.c
randbui.obj : randbui.c
randmui.obj : randmui.c
version.obj : version.c
tal-reent.obj : tal-reent.c
